@@ -34,6 +34,17 @@ import ldap
 import ldap.modlist
 
 
+def _userExists(db, username):
+	sql = 'select id from `jos_users` where username = %s'
+	data = (username)
+
+	userID = db.execSelectQueryScalar(sql, data)
+	
+	if userID is None:
+		return False
+	else:
+		return True
+
 def _del_jos_users(db, username):
 	sql = 'select id from `jos_users` where username = %s'
 	data = (username)
@@ -103,7 +114,7 @@ def _insert_jos_core_acl_groups_aro_map(db, jgidNumber, aroID):
 	db.execQuery(sql, data)
 
 
-def _insert_jos_xprofiles(db, hubname, uid, fname, lname, username, email, pw, joomlagid, joomlagidNumber, gid, gidNumber, loginShell, homeDir):
+def _insert_jos_xprofiles(db, hubname, uid, fname, mname, lname, username, email, pw, joomlagid, joomlagidNumber, gid, gidNumber, loginShell, homeDir):
 	
 	sql = "INSERT INTO `jos_xprofiles` (`uidNumber`, `name`, `username`, `email`, `registerDate`, `gidNumber`, `homeDirectory`, `loginShell`, "
 	sql += "`ftpShell`, `userPassword`, `gid`, `orgtype`, `organization`, `countryresident`, `countryorigin`, `gender`, `url`, `reason`, "
@@ -114,7 +125,7 @@ def _insert_jos_xprofiles(db, hubname, uid, fname, lname, username, email, pw, j
 	data = (uid, fname + ' ' + lname, username, email, datetime.datetime.now(), gidNumber, homeDir, loginShell, 
 	        '/usr/lib/sftp-server', hubzero.config.passwords.MD5PasswordHash(pw), gid, '', '', '', '', '', '', '', 
 	        0, 0, 3, '0000-00-00 00:00:00', 1, '', '', '', '',
-	        '', '', fname, '', lname, '', 0, 0, '', '', None)
+	        '', '', fname, mname, lname, '', 0, 0, '', '', None)
 	db.execQuery(sql, data)
 
 
@@ -185,7 +196,7 @@ def _del_ldap_group(groupName):
 	l.delete_s(dn)
 
 
-def _add_ldap_user(username, password):
+def _add_ldap_user(username, password, uidNumber, homeDir):
 
 	# get ldapManagerUserDN and PW
 	
@@ -196,17 +207,20 @@ def _add_ldap_user(username, password):
 	l = ldap.open("localhost")
 	l.simple_bind_s(hubLDAPAcctMgrDN, hubLDAPAcctMgrPW)
 
-	dn = "cn=" + username + "," + hubLDAPBaseDN
+	dn = "uid=" + username + ",ou=users," + hubLDAPBaseDN
 	attrs = {}
-	attrs['objectclass'] = ['organizationalRole', 'simpleSecurityObject']
+	attrs['objectclass'] = ['top', 'account', 'posixAccount', 'shadowAccount']  
 	attrs['cn'] = username
-	attrs['userPassword'] = "none"
+	attrs['userPassword'] = hubzero.config.passwords.MD5PasswordHash(password)
 	attrs['uid'] = username
+	attrs['uidNumber'] = str(uidNumber)
+	attrs['homeDirectory'] = homeDir
+	
+	# TODO: grab this from the com_members component parm field
+	attrs['gidNumber'] = "100"
 	
 	print "add ldap user dn: " + dn
-	print "ldif: "
-	print attrs
-	
+
 	ldif = ldap.modlist.addModlist(attrs)
 	l.add_s(dn, ldif)
 
@@ -237,7 +251,9 @@ def addhubgroup(db, groupName, groupDescription):
 	return gidNumber
 
 		 
-def addhubuser(hubname, username, fname, lname, email, pw, joomlagid, joomlagidNumber, gid, gidNumber, joomlauserid, loginShell, nocreatehome, homeDir, createGroup, skipldap):
+def addhubuser(hubname, username, fname, mname, lname, email, pw, pwdisabled, joomlagid, 
+               joomlagidNumber, gid, gidNumber, joomlauserid, loginShell, nocreatehome, homeDir, createGroup, 
+               skipldap):
 
 	# grab config options
 	dbPW = hubzero.config.webconfig.getWebConfigDBPassword()
@@ -245,6 +261,10 @@ def addhubuser(hubname, username, fname, lname, email, pw, joomlagid, joomlagidN
 	dbName = hubzero.config.webconfig.getWebConfigDBName()
 	
 	db =  hubzero.data.db.mySql("localhost", dbName, dbUserName, dbPW)
+
+	if _userExists(db, username):
+		print "User already exists" + username
+		return (-1)
 	
 	fullname = fname + ' ' + lname
 
@@ -256,7 +276,7 @@ def addhubuser(hubname, username, fname, lname, email, pw, joomlagid, joomlagidN
 	userID = _insert_jos_users(db, joomlauserid, fullname, username, email, pw, joomlagid, joomlagidNumber)
 	aroID = _insert_jos_core_acl_aro(db, userID, fullname)
 	_insert_jos_core_acl_groups_aro_map(db, joomlagidNumber, aroID)
-	_insert_jos_xprofiles(db, hubname, userID, fname, lname, username, email, pw, joomlagid, joomlagidNumber, gid, gidNumber, loginShell, homeDir)
+	_insert_jos_xprofiles(db, hubname, userID, fname, mname, lname, username, email, pw, joomlagid, joomlagidNumber, gid, gidNumber, loginShell, homeDir)
 	_insert_jos_users_password(db, userID, pw)
 
 
@@ -285,7 +305,9 @@ def addhubuser(hubname, username, fname, lname, email, pw, joomlagid, joomlagidN
 
 	
 	if not skipldap:
-		_add_ldap_user(username, pw)
+		_add_ldap_user(username, pw, userID, homeDir)
+		
+	return(0)
 
 	
 def delhubuser(username):
